using System;
using System.Collections.Generic;
using System.Text;
using System.Threading;

namespace GpioDotNet
{

    /******************************************************************************************
    * This short program demonstrates how to use the .Net wrapper for Compulab's GPIO Driver.
    * Pin 14 on P9(GPIO140) & Pin 1 on P11(GPIO170) should be connected for correct behavior.
    * In addition, the voltage level may be monitored with a DVM or an oscilloscope.
    ******************************************************************************************/
    class Program
    {
        internal const uint OUTPUT_GPIO_NUM = 140;  //Pin 14 on P9 connector located on the SB-T35
        internal const uint INPUT_GPIO_NUM = 170;   //Pin 1 on P11 connector located on the SB-T35
        public static GpioCmT35 hGPIO;


        static void Main(string[] args)
        {
            //Creates an instance of the gpio driver .Net wrapper
            hGPIO = new GpioCmT35();

            //Sets gpio 170 as Input
            hGPIO.SetAsInput(INPUT_GPIO_NUM);

            //sets gpio 140 as Output with a logical value of 1
            hGPIO.SetAsOutput(OUTPUT_GPIO_NUM, GpioLevel.HIGH);

            Thread.Sleep(1000);

            //sets gpio 140 as Output with a logical value of 0
            hGPIO.SetAsOutput(OUTPUT_GPIO_NUM, GpioLevel.LOW);


            //checks wether GPIO direction is setup as input or output
            if ((hGPIO.GetConfiguration(INPUT_GPIO_NUM)) == GpioConfiguration.INPUT)
                System.Console.WriteLine("Gpio" + INPUT_GPIO_NUM + ": INPUT");

            if ((hGPIO.GetConfiguration(OUTPUT_GPIO_NUM)) == GpioConfiguration.OUTPUT)
                System.Console.WriteLine("Gpio" + OUTPUT_GPIO_NUM + ": OUTPUT");


            //checks wether GPIO is setup high or low.
            if ((hGPIO.GetGpioLevel(INPUT_GPIO_NUM)) == GpioLevel.HIGH)
                System.Console.WriteLine("Gpio" + INPUT_GPIO_NUM + ": HIGH");
            else
                System.Console.WriteLine("Gpio" + INPUT_GPIO_NUM + ": LOW");

        }
    }
}
